==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/ux/HyperlinkLabel.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
function _slicedToArray(r, e) { return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t["return"] && (u = t["return"](), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(r) { if (Array.isArray(r)) return r; }
/**
 * @copyright 2020 Tridium, Inc. All Rights Reserved.
 * @author Vikram Nagulan
 */

/* global niagara */
/* eslint-env browser */

/**
 * API Status: **Private**
 * @module nmodule/bajaui/rc/ux/HyperlinkLabel
 */

define(['baja!', 'underscore', 'bajaux/spandrel', 'nmodule/bajaui/rc/ux/Label', 'nmodule/bajaui/rc/binding/impl/widgetEvents', 'nmodule/bajaui/rc/util/pxUtils', 'lex!webEditors', 'log!nmodule/bajaui/rc/ux/HyperlinkLabel'], function (baja, _, spandrel, Label, widgetEvents, pxUtils, lexs, log) {
  'use strict';

  var DEFAULT_ORD = baja.Ord.DEFAULT,
    widgetDefaults = function widgetDefaults() {
      return {
        properties: {
          rootCssClass: 'ux-HyperlinkLabel',
          ord: DEFAULT_ORD,
          blink: false
        }
      };
    },
    _lexs = _slicedToArray(lexs, 1),
    webEditorsLex = _lexs[0],
    logSevere = log.severe.bind(log);

  /**
   * @class
   * @alias module:nmodule/bajaui/rc/ux/HyperlinkLabel
   * @extends {module:nmodule/bajaui/rc/ux/Label}
   */
  return /*#__PURE__*/function (_spandrel) {
    function HyperlinkLabel(params) {
      _classCallCheck(this, HyperlinkLabel);
      return _callSuper(this, HyperlinkLabel, [{
        params: params,
        defaults: widgetDefaults()
      }]);
    }
    _inherits(HyperlinkLabel, _spandrel);
    return _createClass(HyperlinkLabel, [{
      key: "doInitialize",
      value: function doInitialize(dom) {
        var _this = this;
        widgetEvents(this, {
          click: function click(e) {
            if (_this.isEnabled()) {
              e.preventDefault();
              var ord = getWidgetOrd(_this);
              if (ord) {
                return Promise["try"](function () {
                  return niagara.env.hyperlink(ord);
                })["catch"](logSevere);
              }
            } else {
              return false;
            }
          }
        });
      }
    }]);
  }(spandrel(function (model, _ref) {
    var properties = _ref.properties,
      rootElement = _ref.rootElement;
    var _properties = properties,
      ord = _properties.ord,
      enabled = _properties.enabled,
      blink = _properties.blink,
      visible = _properties.visible;
    var outline = document.createElement('span');
    outline.classList.add('-t-HyperlinkLabel-anchor-outline');
    var hyperlinkLabel = rootElement;
    var anchor = document.createElement('a');
    var ordToLink = getOrd(ord, model);
    if (ordToLink && enabled) {
      outline.classList.add('-t-HyperlinkLabel-mouseover');
      var title = webEditorsLex.get({
        key: 'commands.linkTo.displayName',
        args: [ordToLink.toString()]
      });
      anchor.title = title;
      anchor.href = ordToLink.toUri();
    }
    properties = _.omit(properties, 'blink');
    pxUtils.updateBlink([hyperlinkLabel], blink && visible);
    return [{
      dom: outline,
      kids: [{
        dom: anchor,
        kids: [{
          dom: '<span/>',
          type: Label,
          properties: properties,
          value: model
        }]
      }]
    }];
  }, {
    "extends": Label
  }));
  function getOrd(ord, model) {
    // a non-null ord property always wins
    if (!ord.equals(DEFAULT_ORD)) {
      return ord;
    } else {
      // look for a binding with hyperlink
      var bindingList = model.getBindingList();
      if (bindingList) {
        var binding = bindingList.getBindings().find(function (binding) {
          return !binding.getHyperlink().equals(DEFAULT_ORD);
        });
        if (binding) {
          return binding.getHyperlink();
        }
      }
    }
    return null;
  }
  function getWidgetOrd(widget) {
    var ord = widget.properties().getValue('ord');
    return !ord.isNull() && ord;
  }
});

==> Tridium_EMEA_N4_Supervisor-4.14.3.24.zip: rc/ux/HyperlinkLabel.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
function _slicedToArray(r, e) { return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t["return"] && (u = t["return"](), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(r) { if (Array.isArray(r)) return r; }
/**
 * @copyright 2020 Tridium, Inc. All Rights Reserved.
 * @author Vikram Nagulan
 */

/* global niagara */
/* eslint-env browser */

/**
 * API Status: **Private**
 * @module nmodule/bajaui/rc/ux/HyperlinkLabel
 */

define(['baja!', 'underscore', 'bajaux/spandrel', 'Promise', 'nmodule/bajaui/rc/baja/Border', 'nmodule/bajaui/rc/ux/Label', 'nmodule/bajaui/rc/binding/impl/widgetEvents', 'nmodule/bajaui/rc/util/pxUtils', 'lex!webEditors', 'log!nmodule/bajaui/rc/ux/HyperlinkLabel'], function (baja, _, spandrel, Promise, Border, Label, widgetEvents, pxUtils, lexs, log) {
  'use strict';

  var DEFAULT_ORD = baja.Ord.DEFAULT,
    widgetDefaults = function widgetDefaults() {
      return {
        properties: {
          rootCssClass: 'ux-HyperlinkLabel',
          ord: DEFAULT_ORD,
          border: Border.NULL
        }
      };
    },
    _lexs = _slicedToArray(lexs, 1),
    webEditorsLex = _lexs[0],
    logSevere = log.severe.bind(log);

  /**
   * @class
   * @alias module:nmodule/bajaui/rc/ux/HyperlinkLabel
   * @extends {module:nmodule/bajaui/rc/ux/Label}
   */
  return /*#__PURE__*/function (_spandrel) {
    function HyperlinkLabel(params) {
      _classCallCheck(this, HyperlinkLabel);
      return _callSuper(this, HyperlinkLabel, [{
        params: params,
        defaults: widgetDefaults()
      }]);
    }
    _inherits(HyperlinkLabel, _spandrel);
    return _createClass(HyperlinkLabel, [{
      key: "doInitialize",
      value: function doInitialize(dom) {
        var _this = this;
        widgetEvents(this, {
          click: function click(e) {
            if (_this.isEnabled()) {
              e.preventDefault();
              var ord = getWidgetOrd(_this);
              if (ord) {
                return Promise["try"](function () {
                  return niagara.env.hyperlink(ord);
                })["catch"](logSevere);
              }
            } else {
              return false;
            }
          }
        });
      }
    }]);
  }(spandrel(function (model, _ref) {
    var properties = _ref.properties,
      rootElement = _ref.rootElement;
    var _properties = properties,
      ord = _properties.ord,
      enabled = _properties.enabled,
      border = _properties.border,
      blink = _properties.blink,
      visible = _properties.visible;
    var outline = document.createElement('span');
    outline.classList.add('-t-HyperlinkLabel-anchor-outline');
    var hyperlinkLabel = rootElement;
    var anchor = document.createElement('a');
    var ordToLink = getOrd(ord, model);
    if (ordToLink && enabled) {
      outline.classList.add('-t-HyperlinkLabel-mouseover');
      var title = webEditorsLex.get({
        key: 'commands.linkTo.displayName',
        args: [ordToLink.toString()]
      });
      anchor.title = title;
      anchor.href = ordToLink.toUri();
    }
    var borderDiv = document.createElement('div');
    borderDiv.classList.add('-t-Label-border');
    if (border !== Border.NULL) {
      border.applyToElement(borderDiv);
    }
    properties = _.omit(properties, 'blink');
    pxUtils.updateBlink([hyperlinkLabel], blink && visible);
    return [{
      dom: outline,
      kids: [{
        dom: anchor,
        kids: [{
          dom: '<span/>',
          type: Label,
          properties: properties,
          value: model
        }, {
          dom: borderDiv
        }]
      }]
    }];
  }, {
    "extends": Label
  }));
  function getOrd(ord, model) {
    // a non-null ord property always wins
    if (!ord.equals(DEFAULT_ORD)) {
      return ord;
    } else {
      // look for a binding with hyperlink
      var bindingList = model.getBindingList();
      if (bindingList) {
        var binding = bindingList.getBindings().find(function (binding) {
          return !binding.getHyperlink().equals(DEFAULT_ORD);
        });
        if (binding) {
          return binding.getHyperlink();
        }
      }
    }
    return null;
  }
  function getWidgetOrd(widget) {
    var ord = widget.properties().getValue('ord');
    return !ord.isNull() && ord;
  }
});
